@@ -8,8 +8,7 @@ module Network.Wai.Application.Classic.File (
 #if __GLASGOW_HASKELL__ < 709
 import Control.Applicative
 #endif
-import Control.Exception.IOChoice.Lifted
-import Control.Monad.IO.Class (liftIO)
+import Control.Exception.IOChoice
 import Data.ByteString (ByteString)
 import Data.Maybe
 import qualified Data.ByteString.Char8 as BS (concat)
@@ -37,7 +36,7 @@ data HandlerInfo = HandlerInfo FileAppSpec Request Path [Lang]
 langSuffixes :: RequestHeaders -> [Lang]
 langSuffixes hdr = map (\x -> (<.> x)) langs ++ [id, (<.> "en")]
   where
-    langs = map fromByteString $ languages hdr
+    langs = languages hdr
 
 ----------------------------------------------------------------
 
@@ -80,7 +79,7 @@ fileApp cspec spec filei req respond = do
     rfile = redirectPath spec path
     langs = langSuffixes $ requestHeaders req
     noBody st = return $ responseLBS st [] ""
-    bodyStatus st = liftIO (getStatusInfo cspec req langs st)
+    bodyStatus st = getStatusInfo cspec req langs st
                 >>= statusBody st
     statusBody st StatusNone = noBody st
     statusBody st (StatusByteString bd) =
@@ -109,10 +108,9 @@ tryGet hinfo False = tryGetFile hinfo False id
 tryGetFile :: HandlerInfo -> Bool -> Lang -> IO RspSpec
 tryGetFile (HandlerInfo _ req file _) ishtml lang = do
     let file' = pathString $ lang file
-        hdr = newHeader ishtml $ pathByteString file
-    finfo <- fromFileInfo <$> liftIO (getFileInfo req file') -- expecting an error
-    let afile = pathString $ fileinfoName finfo
-    return $ BodyFile ok200 hdr afile
+        hdr = newHeader ishtml file
+    _ <- getFileInfo req file' -- expecting an error
+    return $ BodyFile ok200 hdr file'
 
 ----------------------------------------------------------------
 
@@ -126,7 +124,7 @@ tryRedirect (HandlerInfo spec req _ langs) (Just file) =
 tryRedirectFile :: HandlerInfo -> Lang -> IO RspSpec
 tryRedirectFile (HandlerInfo _ req file _) lang = do
     let file' = pathString $ lang file
-    _ <- liftIO $ getFileInfo req file' -- expecting an error
+    _ <- getFileInfo req file' -- expecting an error
     return $ NoBodyHdr movedPermanently301 hdr
   where
     hdr = redirectHeader req
